==============================
Sample Nexus VXLAN Type Driver
==============================

This sample configuration file can also be viewed in `file form
<../../_static/config-samples/ml2_nexus_vxlan_type_driver.conf.sample>`_.

.. literalinclude:: ../../_static/config-samples/ml2_nexus_vxlan_type_driver.conf.sample
